==> openjdk18-18.0.2.1_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_nn.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_nn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_peo = "gammalpersisk";
        final Object[][] data = new Object[][] {
            { "key.co", "sorteringsrekkjef\u00f8lgje" },
            { "Zsym", "symbol" },
            { "fil", "filippinsk" },
            { "type.nu.greklow", "sm\u00e5 greske tal" },
            { "lus", "lushai" },
            { "den", "slavej" },
            { "luy", "olulujia" },
            { "type.hc.h23", "24-timesystem (0\u201323)" },
            { "bas", "basa" },
            { "type.hc.h24", "24-timesystem (1\u201324)" },
            { "egy", "gammalegyptisk" },
            { "type.nu.mymr", "burmesiske siffer" },
            { "niu", "niuisk" },
            { "lez", "lezghian" },
            { "%%FONUPA", "det uralske fonetiske alfabetet UPA" },
            { "AE", "Dei sameinte arabiske emirata" },
            { "nl_BE", "flamsk" },
            { "zap", "zapotec" },
            { "tvl", "tuvalu" },
            { "001", "verda" },
            { "Hrkt", "japansk stavingsskrifter" },
            { "AT", "Austerrike" },
            { "type.hc.h12", "12-timesystem (1\u201312)" },
            { "type.hc.h11", "12-timesystem (0\u201311)" },
            { "%%AREVELA", "austarmensk" },
            { "%%SAAHO", "saaho-dialekt" },
            { "ceb", "cebuano" },
            { "type.nu.orya", "odia-siffer" },
            { "type.nu.hanidec", "kinesiske desimaltal" },
            { "kum", "kumyk" },
            { "be", "kviterussisk" },
            { "bss", "bakossi" },
            { "gmh", "mellomh\u00f8gtysk" },
            { "rw", "kinjarwanda" },
            { "zbl", "blissymbol" },
            { "kea", "kabuverdianu" },
            { "BL", "Saint Barth\u00e9lemy" },
            { "SB", "Salomon\u00f8yane" },
            { "SC", "Seychellane" },
            { "sc", "sardinsk" },
            { "013", "Sentral-Amerika" },
            { "014", "Aust-Afrika" },
            { "SH", "Saint Helena" },
            { "type.lb.strict", "streng lineskiftstil" },
            { "type.nu.laoo", "laotiske siffer" },
            { "018", "S\u00f8rlege Afrika" },
            { "BY", "Kviterussland" },
            { "Visp", "synleg tale" },
            { "type.nu.arab", "arabisk-indiske siffer" },
            { "type.nu.hebr", "hebraiske tal" },
            { "type.nu.taml", "tamilske tal" },
            { "CC", "Kokos\u00f8yane" },
            { "mzn", "mazanderani" },
            { "type.cf.account", "valutaformat for rekneskapsf\u00f8ring" },
            { "CD", "Kongo-Kinshasa" },
            { "st", "s\u00f8rsotho" },
            { "CF", "Den sentralafrikanske republikken" },
            { "CI", "Elfenbeinskysten" },
            { "type.nu.hantfin", "tradisjonelle kinesiske finanstal" },
            { "%%REVISED", "revidert rettskriving" },
            { "CK", "Cook\u00f8yane" },
            { "asa", "asu (Tanzania)" },
            { "021", "Nordlege Amerika" },
            { "TC", "Turks- og Caicos\u00f8yane" },
            { "TF", "Dei franske s\u00f8rterritoria" },
            { "cu", "kyrkjeslavisk" },
            { "cv", "tsjuvansk" },
            { "TL", "Aust-Timor" },
            { "type.nu.ethi", "etiopiske tal" },
            { "tn", "tswana" },
            { "type.nu.jpan", "japanske tal" },
            { "swb", "shimaore" },
            { "goh", "gammalh\u00f8gtysk" },
            { "type.nu.deva", "devanagari-siffer" },
            { "Zzzz", "ukjend skrift" },
            { "type.nu.armnlow", "sm\u00e5 armenske tal" },
            { "DO", "Den dominikanske republikken" },
            { "rup", "arumensk" },
            { "sga", "gammalirsk" },
            { "030", "Aust-Asia" },
            { "151", "Aust-Europa" },
            { "tyv", "tuvinisk" },
            { "035", "S\u00f8raust-Asia" },
            { "type.co.pinyin", "pinyin-sortering" },
            { "Ital", "gammalitalisk" },
            { "bez", "bena (Tanzania)" },
            { "UM", "USAs ytre sm\u00e5\u00f8yar" },
            { "UN", "SN" },
            { "type.nu.grek", "greske tal" },
            { "tiv", "tivi" },
            { "type.lb.normal", "normal lineskiftstil" },
            { "xal", "kalmykisk" },
            { "type.co.gb2312han", "forenkla kinesisk sortering" },
            { "chg", "tsjagataisk" },
            { "ro_MD", "moldavisk" },
            { "tzm", "sentral-tamazight" },
            { "%%1996", "tysk ortografi fr\u00e5 1996" },
            { "nds_NL", "l\u00e5gsaksisk" },
            { "chr", "cherokee" },
            { "pro", "gammalproven\u00e7alsk" },
            { "VC", "St. Vincent og Grenadinane" },
            { "type.co.big5han", "tradisjonell kinesisk sortering" },
            { "Hanb", "hanb" },
            { "EU", "Den europeiske unionen" },
            { "elx", "elamite" },
            { "VG", "Dei britiske Jomfru\u00f8yane" },
            { "VI", "Dei amerikanske Jomfru\u00f8yane" },
            { "EZ", "eurosona" },
            { "type.nu.gujr", "gujarati-siffer" },
            { "hsb", "h\u00f8gsorbisk" },
            { "Hans", "forenkla" },
            { "type.nu.latn", "vestlege siffer" },
            { "quc", "k\u2019iche" },
            { "FK", "Falklands\u00f8yane" },
            { "nog", "nogai" },
            { "FO", "F\u00e6r\u00f8yane" },
            { "non", "gammalnorsk" },
            { "syr", "syrisk" },
            { "%%AREVMDA", "vestarmensk" },
            { "tkl", "tokelau" },
            { "Xsux", "sumero-akkadisk kileskrift" },
            { "grc", "gammalgresk" },
            { "zgh", "standard marokkansk tamazight" },
            { "pcm", "nigeriansk pidgin" },
            { "ar_001", "moderne standardarabisk" },
            { "Cans", "felles kanadiske urspr\u00e5ksstavingar" },
            { "Latf", "latinsk (frakturvariant)" },
            { "XA", "pseudospr\u00e5k \u2013 aksentar" },
            { "war", "waray" },
            { "XB", "pseudospr\u00e5k \u2013 RTL" },
            { "GS", "S\u00f8r-Georgia og S\u00f8r-Sandwich\u00f8yane" },
            { "Latg", "latinsk (g\u00e6lisk variant)" },
            { "type.nu.hans", "forenkla kinesiske tal" },
            { "type.nu.hant", "tradisjonelle kinesiske tal" },
            { "gv", "manx" },
            { "type.nu.romanlow", "sm\u00e5 romartal" },
            { "Zxxx", "spr\u00e5k utan skrift" },
            { "ckb", "sorani" },
            { "zxx", "utan spr\u00e5kleg innhald" },
            { "HM", "Heard\u00f8ya og McDonald\u00f8yane" },
            { "nqo", "n\u2019ko" },
            { "type.co.standard", "standard sorteringsrekkjef\u00f8lgje" },
            { "Syrc", "syriakisk" },
            { "%%FONIPA", "det internasjonale fonetiske alfabetet (IPA)" },
            { "Syrj", "syriakisk (vestleg variant)" },
            { "IC", "Kanari\u00f8yane" },
            { "Sgnw", "teiknskrift" },
            { "peo", metaValue_peo },
            { "type.nu.tibt", "tibetanske siffer" },
            { "Syre", "syriakisk (estrangelo-variant)" },
            { "zza", "zaza" },
            { "fro", "gammalfransk" },
            { "frs", "austfrisisk" },
            { "type.lb.loose", "laus lineskiftstil" },
            { "type.nu.thai", "thailandske siffer" },
            { "type.nu.geor", "georgiske tal" },
            { "Perm", "gammalpermisk" },
            { "type.nu.beng", "bengalske siffer" },
            { "key.lb", "lineskiftstil" },
            { "%%1606NICT", "nyare mellomfransk til 1606" },
            { "nso", "nordsotho" },
            { "type.nu.telu", "telugu-siffer" },
            { "tog", "tonga (Nyasa)" },
            { "type.nu.knda", "kannada-siffer" },
            { "type.nu.jpanfin", "japanske finanstal" },
            { "kl", "gr\u00f8nlandsk (kalaallisut)" },
            { "KM", "Komorane" },
            { "Zinh", "nedarva" },
            { "Syrn", "syriakisk (austleg variant)" },
            { "KY", "Cayman\u00f8yane" },
            { "Cyrs", "kyrillisk (kyrkjeslavisk variant)" },
            { "type.nu.mlym", "malayalam-siffer" },
            { "ebu", "embu" },
            { "Egyp", "egyptiske hieroglyfar" },
            { "Geok", "khutsuri (asomtavruli og nuskhuri)" },
            { "nds", "l\u00e5gtysk" },
            { "li", "limburgisk" },
            { "fur", "friulisk" },
            { "zh_Hans", "forenkla kinesisk" },
            { "Hung", "gammalungarsk" },
            { "type.nu.hansfin", "forenkla kinesiske finanstal" },
            { "LU", "Luxembourg" },
            { "type.nu.arabext", "utvida arabisk-indiske siffer" },
            { "lad", "ladino" },
            { "type.nu.fullwide", "siffer med full breidd" },
            { "Thaa", "thaana" },
            { "Maya", "maya-hieroglyfar" },
            { "mg", "madagassisk" },
            { "MH", "Marshall\u00f8yane" },
            { "type.co.ducet", "standard Unicode-sorteringsrekkjef\u00f8lgje" },
            { "lrc", "nord-lurisk" },
            { "zh_Hant", "tradisjonell kinesisk" },
            { "MP", "Nord-Marianane" },
            { "alt", "s\u00f8r-altaj" },
            { "type.nu.khmr", "khmer-siffer" },
            { "MV", "Maldivane" },
            { "%%VALENCIA", "valensisk dialekt" },
            { "mdf", "moksha" },
            { "%%BAKU1926", "samla tyrkisk-latinsk alfabet" },
            { "dsb", "l\u00e5gsorbisk" },
            { "Armi", "armisk" },
            { "ne", "nepalsk" },
            { "type.nu.guru", "gurmukhi-siffer" },
            { "Phlp", "salmepahlavi" },
            { "nwc", "klassisk newarisk" },
            { "Hmng", "pahawk hmong" },
            { "udm", "udmurt" },
            { "NO", "Noreg" },
            { "mul", "fleire spr\u00e5k" },
            { "gil", "gilbertese" },
            { "kab", "kabyle" },
            { "car", "carib" },
            { "Limb", "lumbu" },
            { "type.nu.roman", "romartal" },
            { "ang", "gammalengelsk" },
            { "type.nu.tamldec", "tamilske siffer" },
            { "type.nu.armn", "armenske tal" },
            { "krc", "karachay-balkar" },
            { "%%SCOUSE", "scouse-dialekt" },
            { "fa_AF", "dari" },
            { "crs", "seselwa (fransk-kreolsk)" },
            { "Xpeo", metaValue_peo },
            { "key.nu", "tal" },
            { "mfe", "morisyen" },
            { "srn", "sranan tongo" },
            { "type.ca.islamic-civil", "islamsk sivil kalender" },
            { "%%LIPAW", "resian, lipovazdialekt" },
            { "PH", "Filippinane" },
            { "PN", "Pitcairn" },
        };
        return data;
    }
}

==> openjdk19-19_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_nn.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_nn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_peo = "gammalpersisk";
        final Object[][] data = new Object[][] {
            { "key.co", "sorteringsrekkjef\u00f8lgje" },
            { "Zsym", "symbol" },
            { "fil", "filippinsk" },
            { "type.nu.greklow", "sm\u00e5 greske tal" },
            { "lus", "lushai" },
            { "den", "slavej" },
            { "luy", "olulujia" },
            { "type.hc.h23", "24-timesystem (0\u201323)" },
            { "bas", "basa" },
            { "type.hc.h24", "24-timesystem (1\u201324)" },
            { "egy", "gammalegyptisk" },
            { "type.nu.mymr", "burmesiske siffer" },
            { "niu", "niuisk" },
            { "lez", "lezghian" },
            { "%%FONUPA", "det uralske fonetiske alfabetet UPA" },
            { "AE", "Dei sameinte arabiske emirata" },
            { "nl_BE", "flamsk" },
            { "zap", "zapotec" },
            { "tvl", "tuvalu" },
            { "001", "verda" },
            { "Hrkt", "japansk stavingsskrifter" },
            { "AT", "Austerrike" },
            { "type.hc.h12", "12-timesystem (1\u201312)" },
            { "type.hc.h11", "12-timesystem (0\u201311)" },
            { "%%AREVELA", "austarmensk" },
            { "%%SAAHO", "saaho-dialekt" },
            { "ceb", "cebuano" },
            { "type.nu.orya", "odia-siffer" },
            { "type.nu.hanidec", "kinesiske desimaltal" },
            { "kum", "kumyk" },
            { "be", "kviterussisk" },
            { "bss", "bakossi" },
            { "gmh", "mellomh\u00f8gtysk" },
            { "rw", "kinjarwanda" },
            { "zbl", "blissymbol" },
            { "BL", "Saint Barth\u00e9lemy" },
            { "SB", "Salomon\u00f8yane" },
            { "SC", "Seychellane" },
            { "sc", "sardinsk" },
            { "013", "Sentral-Amerika" },
            { "014", "Aust-Afrika" },
            { "SH", "Saint Helena" },
            { "type.lb.strict", "streng lineskiftstil" },
            { "type.nu.laoo", "laotiske siffer" },
            { "018", "S\u00f8rlege Afrika" },
            { "BY", "Kviterussland" },
            { "Visp", "synleg tale" },
            { "type.nu.arab", "arabisk-indiske siffer" },
            { "type.nu.hebr", "hebraiske tal" },
            { "type.nu.taml", "tamilske tal" },
            { "CC", "Kokos\u00f8yane" },
            { "mzn", "mazanderani" },
            { "type.cf.account", "valutaformat for rekneskapsf\u00f8ring" },
            { "CD", "Kongo-Kinshasa" },
            { "st", "s\u00f8rsotho" },
            { "CF", "Den sentralafrikanske republikken" },
            { "CI", "Elfenbeinskysten" },
            { "type.nu.hantfin", "tradisjonelle kinesiske finanstal" },
            { "%%REVISED", "revidert rettskriving" },
            { "CK", "Cook\u00f8yane" },
            { "asa", "asu (Tanzania)" },
            { "021", "Nordlege Amerika" },
            { "TC", "Turks- og Caicos\u00f8yane" },
            { "TF", "Dei franske s\u00f8rterritoria" },
            { "cu", "kyrkjeslavisk" },
            { "cv", "tsjuvansk" },
            { "TL", "Aust-Timor" },
            { "type.nu.ethi", "etiopiske tal" },
            { "tn", "tswana" },
            { "type.nu.jpan", "japanske tal" },
            { "swb", "shimaore" },
            { "goh", "gammalh\u00f8gtysk" },
            { "type.nu.deva", "devanagari-siffer" },
            { "Zzzz", "ukjend skrift" },
            { "type.nu.armnlow", "sm\u00e5 armenske tal" },
            { "DO", "Den dominikanske republikken" },
            { "rup", "arumensk" },
            { "sga", "gammalirsk" },
            { "030", "Aust-Asia" },
            { "151", "Aust-Europa" },
            { "tyv", "tuvinisk" },
            { "035", "S\u00f8raust-Asia" },
            { "type.co.pinyin", "pinyin-sortering" },
            { "Ital", "gammalitalisk" },
            { "bez", "bena (Tanzania)" },
            { "type.d0.hwidth", "halv breidd" },
            { "UM", "USAs ytre sm\u00e5\u00f8yar" },
            { "UN", "SN" },
            { "type.nu.grek", "greske tal" },
            { "tiv", "tivi" },
            { "type.lb.normal", "normal lineskiftstil" },
            { "xal", "kalmykisk" },
            { "type.co.gb2312han", "forenkla kinesisk sortering" },
            { "chg", "tsjagataisk" },
            { "ro_MD", "moldavisk" },
            { "tzm", "sentral-tamazight" },
            { "%%1996", "tysk ortografi fr\u00e5 1996" },
            { "nds_NL", "l\u00e5gsaksisk" },
            { "chr", "cherokee" },
            { "pro", "gammalproven\u00e7alsk" },
            { "VC", "St. Vincent og Grenadinane" },
            { "type.co.big5han", "tradisjonell kinesisk sortering" },
            { "Hanb", "hanb" },
            { "EU", "Den europeiske unionen" },
            { "elx", "elamite" },
            { "VG", "Dei britiske Jomfru\u00f8yane" },
            { "VI", "Dei amerikanske Jomfru\u00f8yane" },
            { "EZ", "eurosona" },
            { "type.nu.gujr", "gujarati-siffer" },
            { "hsb", "h\u00f8gsorbisk" },
            { "Hans", "forenkla" },
            { "type.nu.latn", "vestlege siffer" },
            { "quc", "k\u2019iche" },
            { "FK", "Falklands\u00f8yane" },
            { "nog", "nogai" },
            { "FO", "F\u00e6r\u00f8yane" },
            { "non", "gammalnorsk" },
            { "syr", "syrisk" },
            { "%%AREVMDA", "vestarmensk" },
            { "tkl", "tokelau" },
            { "Xsux", "sumero-akkadisk kileskrift" },
            { "grc", "gammalgresk" },
            { "zgh", "standard marokkansk tamazight" },
            { "pcm", "nigeriansk pidgin" },
            { "ar_001", "moderne standardarabisk" },
            { "Cans", "felles kanadiske urspr\u00e5ksstavingar" },
            { "Latf", "latinsk (frakturvariant)" },
            { "XA", "pseudospr\u00e5k \u2013 aksentar" },
            { "war", "waray" },
            { "XB", "pseudospr\u00e5k \u2013 RTL" },
            { "GS", "S\u00f8r-Georgia og S\u00f8r-Sandwich\u00f8yane" },
            { "Latg", "latinsk (g\u00e6lisk variant)" },
            { "type.nu.hans", "forenkla kinesiske tal" },
            { "type.nu.hant", "tradisjonelle kinesiske tal" },
            { "gv", "manx" },
            { "type.nu.romanlow", "sm\u00e5 romartal" },
            { "Zxxx", "spr\u00e5k utan skrift" },
            { "ckb", "sorani" },
            { "zxx", "utan spr\u00e5kleg innhald" },
            { "HM", "Heard\u00f8ya og McDonald\u00f8yane" },
            { "nqo", "n\u2019ko" },
            { "type.co.standard", "standard sorteringsrekkjef\u00f8lgje" },
            { "Syrc", "syriakisk" },
            { "%%FONIPA", "det internasjonale fonetiske alfabetet (IPA)" },
            { "Syrj", "syriakisk (vestleg variant)" },
            { "IC", "Kanari\u00f8yane" },
            { "Sgnw", "teiknskrift" },
            { "peo", metaValue_peo },
            { "type.nu.tibt", "tibetanske siffer" },
            { "Syre", "syriakisk (estrangelo-variant)" },
            { "zza", "zaza" },
            { "fro", "gammalfransk" },
            { "frs", "austfrisisk" },
            { "type.lb.loose", "laus lineskiftstil" },
            { "type.nu.thai", "thailandske siffer" },
            { "type.nu.geor", "georgiske tal" },
            { "Perm", "gammalpermisk" },
            { "type.nu.beng", "bengalske siffer" },
            { "key.lb", "lineskiftstil" },
            { "%%1606NICT", "nyare mellomfransk til 1606" },
            { "nso", "nordsotho" },
            { "type.nu.telu", "telugu-siffer" },
            { "tog", "tonga (Nyasa)" },
            { "type.nu.knda", "kannada-siffer" },
            { "type.nu.jpanfin", "japanske finanstal" },
            { "kl", "gr\u00f8nlandsk (kalaallisut)" },
            { "KM", "Komorane" },
            { "Zinh", "nedarva" },
            { "Syrn", "syriakisk (austleg variant)" },
            { "KY", "Cayman\u00f8yane" },
            { "Cyrs", "kyrillisk (kyrkjeslavisk variant)" },
            { "gwi", "gwichin" },
            { "type.nu.mlym", "malayalam-siffer" },
            { "ebu", "embu" },
            { "Egyp", "egyptiske hieroglyfar" },
            { "Geok", "khutsuri (asomtavruli og nuskhuri)" },
            { "nds", "l\u00e5gtysk" },
            { "li", "limburgisk" },
            { "fur", "friulisk" },
            { "zh_Hans", "forenkla kinesisk" },
            { "Hung", "gammalungarsk" },
            { "type.nu.hansfin", "forenkla kinesiske finanstal" },
            { "LU", "Luxembourg" },
            { "type.nu.arabext", "utvida arabisk-indiske siffer" },
            { "lad", "ladino" },
            { "type.nu.fullwide", "siffer med full breidd" },
            { "Thaa", "thaana" },
            { "Maya", "maya-hieroglyfar" },
            { "mg", "madagassisk" },
            { "MH", "Marshall\u00f8yane" },
            { "type.co.ducet", "standard Unicode-sorteringsrekkjef\u00f8lgje" },
            { "lrc", "nord-lurisk" },
            { "zh_Hant", "tradisjonell kinesisk" },
            { "MP", "Nord-Marianane" },
            { "alt", "s\u00f8r-altaj" },
            { "type.nu.khmr", "khmer-siffer" },
            { "MV", "Maldivane" },
            { "%%VALENCIA", "valensisk dialekt" },
            { "mdf", "moksha" },
            { "%%BAKU1926", "samla tyrkisk-latinsk alfabet" },
            { "dsb", "l\u00e5gsorbisk" },
            { "Armi", "armisk" },
            { "ne", "nepalsk" },
            { "type.nu.guru", "gurmukhi-siffer" },
            { "Phlp", "salmepahlavi" },
            { "nwc", "klassisk newarisk" },
            { "Hmng", "pahawk hmong" },
            { "udm", "udmurt" },
            { "NO", "Noreg" },
            { "mul", "fleire spr\u00e5k" },
            { "gil", "gilbertese" },
            { "car", "carib" },
            { "Limb", "lumbu" },
            { "type.nu.roman", "romartal" },
            { "ang", "gammalengelsk" },
            { "type.nu.tamldec", "tamilske siffer" },
            { "type.nu.armn", "armenske tal" },
            { "krc", "karachay-balkar" },
            { "%%SCOUSE", "scouse-dialekt" },
            { "fa_AF", "dari" },
            { "crs", "seselwa (fransk-kreolsk)" },
            { "Xpeo", metaValue_peo },
            { "key.nu", "tal" },
            { "mfe", "morisyen" },
            { "srn", "sranan tongo" },
            { "type.ca.islamic-civil", "islamsk sivil kalender" },
            { "%%LIPAW", "resian, lipovazdialekt" },
            { "PH", "Filippinane" },
            { "PN", "Pitcairn" },
            { "type.d0.fwidth", "full breidd" },
        };
        return data;
    }
}
